@@ -1,4 +1,19 @@
 # -*- coding: utf-8 -*-
+#  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
+#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Main module generating the ECS Cluster template.
@@ -8,26 +23,24 @@ That way it is easy for anyone to deploy an instance in standalone if you wanted
 """
 
 from troposphere import Ref, If, GetAtt
-from troposphere.cloudformation import Stack
 from ecs_composex.compute import compute_params, compute_conditions
 from ecs_composex.compute.hosts_template import add_hosts_resources
 from ecs_composex.compute.spot_fleet import (
     generate_spot_fleet_template,
     DEFAULT_SPOT_CONFIG,
 )
-from ecs_composex.common import (
-    build_template,
-    KEYISSET,
-    LOG,
-    add_parameters,
-    write_template_to_file,
-)
+from ecs_composex.common import build_template, KEYISSET, LOG, add_parameters
 from ecs_composex.common import cfn_conditions
-from ecs_composex.common.cfn_params import ROOT_STACK_NAME, ROOT_STACK_NAME_T, USE_FLEET, USE_ONDEMAND
-from ecs_composex.common.templates import upload_template
+from ecs_composex.common.cfn_params import (
+    ROOT_STACK_NAME,
+    ROOT_STACK_NAME_T,
+    USE_FLEET,
+    USE_ONDEMAND,
+)
 from ecs_composex.vpc import vpc_params
 from ecs_composex.ecs.ecs_params import CLUSTER_NAME
 from ecs_composex.common.tagging import add_object_tags
+from ecs_composex.common.stacks import ComposeXStack
 
 
 def add_spotfleet_stack(
@@ -70,7 +83,9 @@ def add_spotfleet_stack(
     if spot_config:
         kwargs.update({"spot_config": spot_config})
     else:
-        LOG.warn("No spot_config set in configs of ComposeX File. Setting to defaults")
+        LOG.warning(
+            "No spot_config set in configs of ComposeX File. Setting to defaults"
+        )
         kwargs.update({"spot_config": DEFAULT_SPOT_CONFIG})
     fleet_template = generate_spot_fleet_template(region_azs, **kwargs)
     if tags and tags[0]:
@@ -79,21 +94,13 @@ def add_spotfleet_stack(
             parameters.update({tag.title: Ref(tag.title)})
         for resource in fleet_template.resources:
             add_object_tags(fleet_template.resources[resource], tags[1])
-    fleet_template_url = upload_template(
-        fleet_template.to_json(), kwargs["BucketName"], "spot_fleet.json"
-    )
-    if not fleet_template_url:
-        LOG.warn(
-            "Fleet template URL not returned. Not adding SpotFleet to Cluster stack"
-        )
-        return
-    write_template_to_file(fleet_template, "/tmp/spot_fleet.yml")
     template.add_resource(
-        Stack(
+        ComposeXStack(
             "SpotFleet",
+            template=fleet_template,
             Condition=cfn_conditions.USE_SPOT_CON_T,
-            TemplateURL=fleet_template_url,
             Parameters=parameters,
+            **kwargs
         )
     )
 
@@ -134,9 +141,7 @@ def generate_compute_template(region_azs, compose_content=None, tags=None, **kwa
     template.add_condition(
         compute_conditions.MAX_IS_MIN_T, compute_conditions.MAX_IS_MIN
     )
-    template.add_condition(
-        cfn_conditions.USE_SPOT_CON_T, cfn_conditions.USE_SPOT_CON
-    )
+    template.add_condition(cfn_conditions.USE_SPOT_CON_T, cfn_conditions.USE_SPOT_CON)
     launch_template = add_hosts_resources(template)
     add_spotfleet_stack(
         template, region_azs, compose_content, launch_template, tags, **kwargs
