@@ -1,49 +1,55 @@
 # -*- coding: utf-8 -*-
+#  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
+#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """Generates the individual SQS Queues templates."""
 
-import os
+from troposphere import Tags, Sub, GetAtt, If, Ref
+from troposphere.sqs import Queue, RedrivePolicy
+from troposphere.ssm import Parameter as SsmParameter
 
-from troposphere import (
-    Tags, Sub, GetAtt,
-    ImportValue, If, Ref
-)
-from troposphere.cloudformation import Stack
-from troposphere.sqs import (
-    Queue, RedrivePolicy
-)
-from troposphere.ssm import (
-    Parameter as SsmParameter
-)
-
-from ecs_composex.common.tagging import add_object_tags, generate_tags_parameters
 from ecs_composex.common import (
-    build_template, add_parameters,
-    cfn_params, KEYISSET, KEYPRESENT, LOG
+    build_template,
+    add_parameters,
+    cfn_params,
+    KEYISSET,
+    KEYPRESENT,
+    LOG,
 )
 from ecs_composex.common import validate_kwargs
 from ecs_composex.common.cfn_conditions import (
     USE_SSM_ONLY_T,
     USE_SSM_EXPORTS_T,
-    USE_STACK_NAME_CON_T
-)
-from ecs_composex.common.cfn_params import (
-    ROOT_STACK_NAME,
-    ROOT_STACK_NAME_T
+    USE_STACK_NAME_CON_T,
 )
+from ecs_composex.common.cfn_params import ROOT_STACK_NAME, ROOT_STACK_NAME_T
 from ecs_composex.common.outputs import formatted_outputs
-from ecs_composex.common.templates import (
-    upload_template
-)
+from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.common.tagging import add_object_tags, generate_tags_parameters
+from ecs_composex.sqs.sqs_params import RES_KEY, SQS_SSM_PREFIX
 from ecs_composex.sqs.sqs_params import (
-    SQS_NAME_T, SQS_NAME,
-    DLQ_NAME_T, DLQ_NAME,
-    SQS_ARN_T
+    SQS_NAME_T,
+    SQS_NAME,
+    DLQ_NAME_T,
+    DLQ_NAME,
+    SQS_ARN_T,
+    DLQ_ARN,
+    DLQ_ARN_T,
 )
 
-RES_KEY = f"x-{os.path.basename(os.path.dirname(os.path.abspath(__file__)))}"
-SQS_SSM_PREFIX = f"/{RES_KEY}/"
-
 
 def define_queue_tags(properties, queue_name):
     """
@@ -58,16 +64,16 @@ def define_queue_tags(properties, queue_name):
     :rtype: troposphere.Tags
     """
     tag_name_exists = False
-    if KEYISSET('Tags', properties):
-        for key in properties['Tags']:
-            if key == 'Name':
+    if KEYISSET("Tags", properties):
+        for key in properties["Tags"]:
+            if key == "Name":
                 tag_name_exists = True
     else:
-        properties['Tags'] = {}
+        properties["Tags"] = {}
 
     if not tag_name_exists:
-        properties['Tags']['Name'] = queue_name
-    return Tags(properties['Tags'])
+        properties["Tags"]["Name"] = queue_name
+    return Tags(properties["Tags"])
 
 
 def add_redrive_policy(queue_tpl, queue_name, properties, dlq_name):
@@ -86,25 +92,26 @@ def add_redrive_policy(queue_tpl, queue_name, properties, dlq_name):
     :returns: dict containing the RedrivePolicy
     :rtype: dict
     """
-    ssm_string = f"/${{{ROOT_STACK_NAME_T}}}{SQS_SSM_PREFIX}${{{DLQ_NAME_T}}}/{SQS_ARN_T}"
-    ssm_resolve = Sub(r'{{resolve:ssm:%s:1}}' % (ssm_string))
-    cfn_import = ImportValue(
-        Sub(
-            f"${{{ROOT_STACK_NAME_T}}}"
-            f"-${{{DLQ_NAME_T}}}"
-            f"-{SQS_ARN_T}"
-        )
-    )
-    redrive_queue_import = If(
-        USE_SSM_ONLY_T,
-        ssm_resolve,
-        cfn_import
+    ssm_string = (
+        f"/${{{ROOT_STACK_NAME_T}}}{SQS_SSM_PREFIX}${{{DLQ_NAME_T}}}/{SQS_ARN_T}"
     )
+    ssm_resolve = Sub(r"{{resolve:ssm:%s:1}}" % (ssm_string))
+    # cfn_import = ImportValue(
+    #     Sub(
+    #         f"${{{ROOT_STACK_NAME_T}}}"
+    #         f"{DELIM}"
+    #         f"${{{DLQ_NAME_T}}}"
+    #         f"{DELIM}"
+    #         f"{SQS_ARN_T}"
+    #     )
+    # )
+    redrive_queue_import = If(USE_SSM_ONLY_T, ssm_resolve, Ref(DLQ_ARN))
+    queue_tpl.add_parameter(DLQ_ARN)
     queue_tpl.add_parameter(DLQ_NAME)
-    policy = properties['RedrivePolicy']
-    policy['deadLetterTargetArn'] = redrive_queue_import
+    policy = properties["RedrivePolicy"]
+    policy["deadLetterTargetArn"] = redrive_queue_import
     policy_obj = RedrivePolicy(**policy)
-    return {'RedrivePolicy': policy_obj}
+    return {"RedrivePolicy": policy_obj}
 
 
 def add_ssm_parameters(src_template, queue_obj):
@@ -119,24 +126,24 @@ def add_ssm_parameters(src_template, queue_obj):
     ssm_name_string = f"/${{{ROOT_STACK_NAME_T}}}{SQS_SSM_PREFIX}${{{SQS_NAME_T}}}"
     LOG.debug(ssm_name_string)
     SsmParameter(
-        'QueueArnSsmParameter',
+        "QueueArnSsmParameter",
         template=src_template,
         Condition=USE_SSM_EXPORTS_T,
         DependsOn=[queue_obj],
         Name=Sub(f"{ssm_name_string}/{SQS_ARN_T}"),
-        Value=GetAtt(queue_obj, 'Arn'),
-        Tier='Standard',
-        Type='String'
+        Value=GetAtt(queue_obj, "Arn"),
+        Tier="Standard",
+        Type="String",
     )
     SsmParameter(
-        'QueueNameSsmParameter',
+        "QueueNameSsmParameter",
         template=src_template,
         Condition=USE_SSM_EXPORTS_T,
         DependsOn=[queue_obj],
         Name=Sub(f"{ssm_name_string}/{SQS_NAME_T}"),
-        Value=GetAtt(queue_obj, 'QueueName'),
-        Tier='Standard',
-        Type='String'
+        Value=GetAtt(queue_obj, "QueueName"),
+        Tier="Standard",
+        Type="String",
     )
 
 
@@ -144,10 +151,14 @@ def generate_queue_template(queue_name, properties, redrive_queue=None, tags=Non
     """
     Function that generates a single queue template
 
+    :param redrive_queue: SQS Redrive queue for DLQ
+    :type redrive_queue: str
     :param queue_name: Name of the Queue as defined in ComposeX File
     :type queue_name: str
     :param properties: The queue properties
     :type properties: dict
+    :param tags: tags to add to the queue
+    :type tags: troposphere.Tags
 
     :returns: queue_template
     :rtype: troposphere.Template
@@ -155,36 +166,34 @@ def generate_queue_template(queue_name, properties, redrive_queue=None, tags=Non
     if not queue_name:
         raise TypeError("Parameter queue_name must be a non-empty string")
     queue_template = build_template(
-        f"Queue {queue_name} in {{{ROOT_STACK_NAME_T}}}",
-        [SQS_NAME]
+        f"Queue {queue_name} in {{{ROOT_STACK_NAME_T}}}", [SQS_NAME]
     )
     if redrive_queue is not None:
-        properties.update(add_redrive_policy(
-            queue_template, queue_name, properties, redrive_queue)
+        properties.update(
+            add_redrive_policy(queue_template, queue_name, properties, redrive_queue)
         )
-    properties['Tags'] = define_queue_tags(properties, queue_name)
-    if 'QueueName' in properties.keys():
-        properties.pop('QueueName')
-        properties['QueueName'] = Sub(
+    properties["Tags"] = define_queue_tags(properties, queue_name)
+    if "QueueName" in properties.keys():
+        properties.pop("QueueName")
+        properties["QueueName"] = Sub(
             f"${{{ROOT_STACK_NAME_T}}}-${properties['QueueName']}"
         )
     else:
-        properties['QueueName'] = Sub(
-            f"${{{ROOT_STACK_NAME_T}}}-${{{SQS_NAME_T}}}"
-        )
+        properties["QueueName"] = Sub(f"${{{ROOT_STACK_NAME_T}}}-${{{SQS_NAME_T}}}")
     queue = Queue(queue_name, template=queue_template, **properties)
     if tags:
         add_object_tags(queue, tags)
     add_ssm_parameters(queue_template, queue)
-    cfn_prefix = f"${{{ROOT_STACK_NAME_T}}}-${{{SQS_NAME_T}}}"
-    queue_template.add_output(formatted_outputs(
-        [
-            {SQS_NAME_T: GetAtt(queue, 'QueueName')},
-            {SQS_ARN_T: GetAtt(queue, 'Arn')}
-        ],
-        export=True,
-        prefix=cfn_prefix
-    ))
+    queue_template.add_output(
+        formatted_outputs(
+            [
+                {SQS_NAME_T: GetAtt(queue, SQS_NAME_T)},
+                {SQS_ARN_T: GetAtt(queue, "Arn")},
+            ],
+            obj_name=SQS_NAME,
+            export=True,
+        )
+    )
     return queue_template
 
 
@@ -192,6 +201,7 @@ def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
     """
     Function to define the Queue template settings for the Nested Stack
 
+    :param tags: tags to add to the resources of the stack.
     :param queue_name: Name of the queue as defined in Docker ComposeX file
     :param queue: the queue
     :param queues: all the queues in a list
@@ -199,36 +209,36 @@ def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
     :param kwargs: optional arguments
 
     :return: Queue Stack object
-    :rtype: troposphere.cloudformation.Stack
+    :rtype: ecs_composex.common.files.ComposeXStack
     """
     depends_on = []
     parameters = {
         SQS_NAME_T: queue_name,
         ROOT_STACK_NAME_T: If(
-            USE_STACK_NAME_CON_T,
-            Ref('AWS::StackName'),
-            Ref(ROOT_STACK_NAME)
+            USE_STACK_NAME_CON_T, Ref("AWS::StackName"), Ref(ROOT_STACK_NAME)
         ),
         cfn_params.USE_CFN_EXPORTS_T: Ref(cfn_params.USE_CFN_EXPORTS),
-        cfn_params.USE_SSM_EXPORTS_T: Ref(cfn_params.USE_SSM_EXPORTS)
+        cfn_params.USE_SSM_EXPORTS_T: Ref(cfn_params.USE_SSM_EXPORTS),
     }
-    if KEYPRESENT('Properties', queue):
-        properties = queue['Properties']
+    if KEYPRESENT("Properties", queue):
+        properties = queue["Properties"]
     else:
         properties = {}
-    if KEYISSET('RedrivePolicy', properties):
-        redrive_target = properties['RedrivePolicy']['deadLetterTargetArn']
+    if KEYISSET("RedrivePolicy", properties):
+        redrive_target = properties["RedrivePolicy"]["deadLetterTargetArn"]
         if redrive_target not in queues:
             raise KeyError(
-                f'Queue {redrive_target} defined as DLQ for {queue_name} but is not defined'
+                f"Queue {redrive_target} defined as DLQ for {queue_name} but is not defined"
             )
         depends_on.append(redrive_target)
-        parameters.update({DLQ_NAME_T: redrive_target})
+        parameters.update(
+            {
+                DLQ_ARN_T: GetAtt(redrive_target, f"Outputs.{SQS_ARN_T}"),
+                DLQ_NAME_T: GetAtt(redrive_target, f"Outputs.{SQS_NAME_T}"),
+            }
+        )
         queue_tpl = generate_queue_template(
-            queue_name,
-            properties,
-            redrive_target,
-            tags=tags[1]
+            queue_name, properties, redrive_target, tags=tags[1]
         )
     else:
         queue_tpl = generate_queue_template(queue_name, properties, tags=tags[1])
@@ -238,17 +248,12 @@ def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
             parameters.update({tag.title: Ref(tag.title)})
     LOG.debug(parameters)
     LOG.debug(session)
-    template_url = upload_template(
-            template_body=queue_tpl.to_json(),
-            bucket_name=kwargs['BucketName'],
-            file_name=f'{queue_name}.json',
-            session=session
-    )
-    queue_stack = Stack(
+    queue_stack = ComposeXStack(
         queue_name,
+        template=queue_tpl,
         Parameters=parameters,
         DependsOn=depends_on,
-        TemplateURL=template_url
+        **kwargs,
     )
     return queue_stack
 
@@ -266,9 +271,9 @@ def generate_sqs_root_template(compose_content, session, **kwargs):
     :return: SQS Root/Parent template
     :rtype: troposphere.Template
     """
-    validate_kwargs(['BucketName'], kwargs)
-    description = 'Root SQS Template'
-    if KEYISSET('EnvName', kwargs):
+    validate_kwargs(["BucketName"], kwargs)
+    description = "Root SQS Template"
+    if KEYISSET("EnvName", kwargs):
         description = f"Root SQS Template for {kwargs['EnvName']}"
     root_tpl = build_template(description)
     params_and_tags = generate_tags_parameters(compose_content)
@@ -279,7 +284,12 @@ def generate_sqs_root_template(compose_content, session, **kwargs):
         LOG.debug(queue_name)
         LOG.debug(session)
         queue_stack = add_queue_stack(
-            queue_name, queues[queue_name], queues.keys(), session, params_and_tags, **kwargs
+            queue_name,
+            queues[queue_name],
+            queues.keys(),
+            session,
+            params_and_tags,
+            **kwargs,
         )
         root_tpl.add_resource(queue_stack)
     return root_tpl
