@@ -1,4 +1,19 @@
 # -*- coding: utf-8 -*-
+#  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
+#  Copyright (C) 2020  John Mille <john@lambda-my-aws.io>
+#
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 Functions to add the three VPC layer type subnets:
@@ -18,12 +33,14 @@ respective AZ
 
 from string import ascii_lowercase as alpha
 from troposphere.ec2 import (
-    Subnet, SubnetRouteTableAssociation,
-    NatGateway, EIP, Route, RouteTable
-)
-from troposphere import (
-    GetAtt, Tags, Ref, Sub, If
+    Subnet,
+    SubnetRouteTableAssociation,
+    NatGateway,
+    EIP,
+    Route,
+    RouteTable,
 )
+from troposphere import GetAtt, Tags, Ref, Sub, If
 
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
@@ -40,33 +57,34 @@ def add_storage_subnets(template, vpc, az_range, layers):
     :returns: tuple() list of rtb, list of subnets
     """
     rtb = RouteTable(
-        'StorageRtb',
+        "StorageRtb",
         template=template,
         VpcId=Ref(vpc),
-        Tags=Tags(Name='StorageRtb') + Tags({'vpc:usage': 'storage'})
+        Tags=Tags(Name="StorageRtb") + Tags({"vpc:usage": "storage"}),
     )
 
     subnets = []
-    for count, subnet_cidr in zip(az_range, layers['stor']):
+    for count, subnet_cidr in zip(az_range, layers["stor"]):
         subnet = Subnet(
-            f'StorageSubnet{alpha[count].upper()}',
+            f"StorageSubnet{alpha[count].upper()}",
             template=template,
             CidrBlock=subnet_cidr,
             VpcId=Ref(vpc),
-            AvailabilityZone=Sub(f'${{AWS::Region}}{alpha[count]}'),
+            AvailabilityZone=Sub(f"${{AWS::Region}}{alpha[count]}"),
             Tags=Tags(
                 Name=If(
                     USE_STACK_NAME_CON_T,
-                    Sub(f'${{AWS::StackName}}-Storage-{alpha[count]}'),
-                    Sub(f'${{{ROOT_STACK_NAME_T}}}-Storage-{alpha[count]}')
+                    Sub(f"${{AWS::StackName}}-Storage-{alpha[count]}"),
+                    Sub(f"${{{ROOT_STACK_NAME_T}}}-Storage-{alpha[count]}"),
                 ),
-            ) + Tags({'vpc:usage': 'storage'})
+            )
+            + Tags({"vpc:usage": "storage"}),
         )
         SubnetRouteTableAssociation(
-            f'StorageSubnetAssoc{alpha[count].upper()}',
+            f"StorageSubnetAssoc{alpha[count].upper()}",
             template=template,
             SubnetId=Ref(subnet),
-            RouteTableId=Ref(rtb)
+            RouteTableId=Ref(rtb),
         )
         subnets.append(subnet)
     return ([rtb], subnets)
@@ -83,54 +101,53 @@ def add_public_subnets(template, vpc, az_range, layers, igw, single_nat):
     :returns: tuple() list of rtb, list of subnets, list of nats
     """
     rtb = RouteTable(
-        'PublicRtb',
+        "PublicRtb",
         template=template,
         VpcId=Ref(vpc),
-        Tags=Tags(Name='PublicRtb') + Tags({'vpc:usage': 'public'})
+        Tags=Tags(Name="PublicRtb") + Tags({"vpc:usage": "public"}),
     )
     Route(
-        'PublicDefaultRoute',
+        "PublicDefaultRoute",
         template=template,
         GatewayId=Ref(igw),
         RouteTableId=Ref(rtb),
-        DestinationCidrBlock='0.0.0.0/0'
+        DestinationCidrBlock="0.0.0.0/0",
     )
     subnets = []
     nats = []
-    for count, subnet_cidr in zip(az_range, layers['pub']):
+    for count, subnet_cidr in zip(az_range, layers["pub"]):
         subnet = Subnet(
-            f'PublicSubnet{alpha[count].upper()}',
+            f"PublicSubnet{alpha[count].upper()}",
             template=template,
             CidrBlock=subnet_cidr,
             VpcId=Ref(vpc),
-            AvailabilityZone=Sub(f'${{AWS::Region}}{alpha[count]}'),
+            AvailabilityZone=Sub(f"${{AWS::Region}}{alpha[count]}"),
             MapPublicIpOnLaunch=True,
             Tags=Tags(
                 Name=If(
                     USE_STACK_NAME_CON_T,
-                    Sub(f'${{AWS::StackName}}-Public-{alpha[count]}'),
-                    Sub(f'${{{ROOT_STACK_NAME_T}}}-Public-{alpha[count]}')
+                    Sub(f"${{AWS::StackName}}-Public-{alpha[count]}"),
+                    Sub(f"${{{ROOT_STACK_NAME_T}}}-Public-{alpha[count]}"),
                 ),
-            ) + Tags({'30-automation:usage': 'public'})
+            )
+            + Tags({"30-automation:usage": "public"}),
         )
         if (single_nat and not nats) or not single_nat:
             eip = EIP(
-                f"NatGatewayEip{alpha[count].upper()}",
-                template=template,
-                Domain='vpc'
+                f"NatGatewayEip{alpha[count].upper()}", template=template, Domain="vpc"
             )
             nat = NatGateway(
                 f"NatGatewayAz{alpha[count].upper()}",
                 template=template,
-                AllocationId=GetAtt(eip, 'AllocationId'),
-                SubnetId=Ref(subnet)
+                AllocationId=GetAtt(eip, "AllocationId"),
+                SubnetId=Ref(subnet),
             )
             nats.append(nat)
         SubnetRouteTableAssociation(
-            f'PublicSubnetsRtbAssoc{alpha[count].upper()}',
+            f"PublicSubnetsRtbAssoc{alpha[count].upper()}",
             template=template,
             RouteTableId=Ref(rtb),
-            SubnetId=Ref(subnet)
+            SubnetId=Ref(subnet),
         )
         subnets.append(subnet)
     return ([rtb], subnets, nats)
@@ -154,40 +171,41 @@ def add_apps_subnets(template, vpc, az_range, layers, nats):
         nats = []
         for az in az_range:
             nats.append(primary_nat)
-    for count, subnet_cidr, nat in zip(az_range, layers['app'], nats):
+    for count, subnet_cidr, nat in zip(az_range, layers["app"], nats):
         suffix = alpha[count].upper()
         subnet = Subnet(
-            f'AppSubnet{suffix}',
+            f"AppSubnet{suffix}",
             template=template,
             CidrBlock=subnet_cidr,
             VpcId=Ref(vpc),
-            AvailabilityZone=Sub(f'${{AWS::Region}}{alpha[count]}'),
+            AvailabilityZone=Sub(f"${{AWS::Region}}{alpha[count]}"),
             Tags=Tags(
                 Name=If(
                     USE_STACK_NAME_CON_T,
-                    Sub(f'${{AWS::StackName}}-App-{alpha[count]}'),
-                    Sub(f'${{{ROOT_STACK_NAME_T}}}-App-{alpha[count]}')
+                    Sub(f"${{AWS::StackName}}-App-{alpha[count]}"),
+                    Sub(f"${{{ROOT_STACK_NAME_T}}}-App-{alpha[count]}"),
                 ),
-            ) + Tags({'vpc:usage': 'application'})
+            )
+            + Tags({"vpc:usage": "application"}),
         )
         rtb = RouteTable(
-            f'AppRtb{alpha[count].upper()}',
+            f"AppRtb{alpha[count].upper()}",
             template=template,
             VpcId=Ref(vpc),
-            Tags=Tags(Name=f'AppRtb{alpha[count].upper()}')
+            Tags=Tags(Name=f"AppRtb{alpha[count].upper()}"),
         )
         Route(
-            f'AppRoute{alpha[count].upper()}',
+            f"AppRoute{alpha[count].upper()}",
             template=template,
             NatGatewayId=Ref(nat),
             RouteTableId=Ref(rtb),
-            DestinationCidrBlock='0.0.0.0/0'
+            DestinationCidrBlock="0.0.0.0/0",
         )
         SubnetRouteTableAssociation(
-            f'SubnetRtbAssoc{alpha[count].upper()}',
+            f"SubnetRtbAssoc{alpha[count].upper()}",
             template=template,
             RouteTableId=Ref(rtb),
-            SubnetId=Ref(subnet)
+            SubnetId=Ref(subnet),
         )
         rtbs.append(rtb)
         subnets.append(subnet)
