@@ -4,51 +4,47 @@
 import os
 import yaml
 import pytest
+
 try:
     from yaml import CLoader as Loader
 except ImportError:
     from yaml import Loader
 
 from ecs_composex.common import build_template
-from ecs_composex.ecs.ecs_iam import (
-    add_service_roles,
-    assign_x_resources_to_service
-)
+from ecs_composex.ecs.ecs_iam import add_service_roles
 
 try:
-    BUCKET = os.environ['KNOWN_BUCKET']
+    BUCKET = os.environ["KNOWN_BUCKET"]
 except KeyError:
-    BUCKET = 'lambda-dev-eu-west-1'
+    BUCKET = "lambda-dev-eu-west-1"
 
 
 HERE = os.path.dirname(os.path.abspath(__file__))
 
+
 @pytest.fixture
 def content():
     """
     Opens the file and passes the content around
     """
-    with open(f"{HERE}/services_with_queues.yml", 'r') as fd:
+    with open(f"{HERE}/services_with_queues.yml", "r") as fd:
         content = yaml.load(fd.read(), Loader=Loader)
     return content
 
+
 @pytest.fixture
 def config():
     """
     Config object
     """
-    return {
-        'BucketName': BUCKET,
-        'EnvName': 'abcd',
-        'Debug': True
-    }
+    return {"BucketName": BUCKET, "EnvName": "abcd", "Debug": True}
 
 
 def test_ecs_roles(config):
     """
     Tests the creation of service roles
     """
-    tmp_tpl = build_template('Tmp template')
+    tmp_tpl = build_template("Tmp template")
     add_service_roles(tmp_tpl)
 
 
@@ -56,6 +52,5 @@ def test_ecs_roles_permissions(content, config):
     """
     Function to test
     """
-    tmp_tpl = build_template('TMP Template')
+    tmp_tpl = build_template("TMP Template")
     add_service_roles(tmp_tpl)
-    assign_x_resources_to_service(content, 'app01', tmp_tpl, **config)
